Method: Awestruct::Handlers::VerbatimFileHandler#read_content

Defined in:
lib/awestruct/handlers/verbatim_file_handler.rb

#read_contentObject

Read file in binary mode so that it can be copied to the generated site as is



7
8
9
# File 'lib/awestruct/handlers/verbatim_file_handler.rb', line 7

def read_content
  File.open(@path, 'rb') {|is| is.read }
end